@@ -8,10 +8,9 @@ if ($] >= 5.015) {
     warnings::register_categories(qw/version/);
 }
 
-use vars qw(@ISA $VERSION $CLASS $STRICT $LAX *declare *qv);
-
-$VERSION = 0.9918;
-$CLASS = 'version';
+our $VERSION = '0.9933';
+our $CLASS = 'version';
+our (@ISA, $STRICT, $LAX);
 
 # !!!!Delete this next block completely when adding to Perl core!!!!
 {
@@ -29,6 +28,10 @@ $CLASS = 'version';
 	*version::new = \&version::vpp::new;
 	*version::numify = \&version::vpp::numify;
 	*version::normal = \&version::vpp::normal;
+	*version::to_decimal = \&version::vpp::to_decimal;
+	*version::to_dotted_decimal = \&version::vpp::to_dotted_decimal;
+	*version::tuple = \&version::vpp::tuple;
+	*version::from_tuple = \&version::vpp::from_tuple;
 	if ($] >= 5.009000) {
 	    no strict 'refs';
 	    *version::stringify = \&version::vpp::stringify;
@@ -48,6 +51,10 @@ $CLASS = 'version';
 	*version::new = \&version::vxs::new;
 	*version::numify = \&version::vxs::numify;
 	*version::normal = \&version::vxs::normal;
+	*version::to_decimal = \&version::vxs::to_decimal;
+	*version::to_dotted_decimal = \&version::vxs::to_dotted_decimal;
+	*version::tuple = \&version::vxs::tuple;
+	*version::from_tuple = \&version::vxs::from_tuple;
 	if ($] >= 5.009000) {
 	    no strict 'refs';
 	    *version::stringify = \&version::vxs::stringify;
